Jirahub: a package for syncing JIRA tickets and GitHub issues
-------------------------------------------------------------

This package provides a configurable tool for syncing tickets in a JIRA project and issues in a GitHub repository.

Please see `the documentation <http://jirahub.readthedocs.io/en/latest/>`_ for more information

License
-------

This project is Copyright (c) Association of Universities for Research in Astronomy (AURA) and licensed under the terms of the BSD 3-Clause license. See `LICENSE.rst <LICENSE.rst>`_ for more information.
